@@ -29,6 +29,7 @@ from .ircevent import IrcEvent
 
 ## basic imports
 
+from errno import EAGAIN, EBADF, EPIPE
 import time
 import _thread
 import socket
@@ -225,10 +226,10 @@ class Irc(BotBase):
                     doreconnect = 1
                     break
                 continue
-            except socket.sslerror as ex:
+            except ssl.SSLError as ex:
                 self.error = str(ex)
                 if self.stopped or self.stopreadloop: break
-                if not 'timed out' in str(ex):
+                if not ex.ETIMEOUT:
                     handle_exception()
                     doreconnect = 1
                     break
@@ -245,10 +246,9 @@ class Irc(BotBase):
                 continue
             except IOError as ex:
                 self.error = str(ex)
-                if self.blocking and 'temporarily' in str(ex):
-                    logging.warn("iorror: %s (%s)" % (self.error, self.cfg.name))
-                    time.sleep(1)
-                    continue
+                if ex.errno == EAGAIN: time.sleep(0.5) ; continue
+                elif ex.errno != EPIPE and ex.errno != EBADF: raise
+                else: time.sleep(0.5) ; continue
                 if not self.stopped:
                     logging.error('connecting error: %s (%s)' % (str(ex), self.cfg.name))
                     handle_exception()
@@ -256,10 +256,9 @@ class Irc(BotBase):
                 break
             except socket.error as ex:
                 self.error = str(ex)
-                if self.blocking and 'temporarily' in str(ex):
-                    logging.warn("ioerror: %s (%s)" % (self.error, self.cfg.name))
-                    time.sleep(0.5)
-                    continue
+                if ex.errno == EAGAIN: time.sleep(0.5) ; continue
+                elif ex.errno != EPIPE and ex.errno != EBADF: raise
+                else: time.sleep(0.5) ; continue
                 if not self.stopped:
                     logging.error('connecting error: %s (%s)' % (str(ex), self.cfg.name))
                     doreconnect = 1
@@ -361,7 +360,7 @@ class Irc(BotBase):
 
     def broadcast(self, txt):
         """ broadcast txt to all joined channels. """
-        for i in self.state['joinedchannels']:
+        for i in self.cfg.channels:
             self.say(i, txt, speed=1)
 
     def normalize(self, what):
@@ -461,19 +460,19 @@ class Irc(BotBase):
             self._raw('JOIN %s %s' % (channel, password))
         else: self._raw('JOIN %s' % channel)
         if self.state:
-            if channel not in self.state.data.joinedchannels:
-                self.state.data.joinedchannels.append(channel)
-                self.state.save()
+            if channel not in self.cfg.channels:
+                self.cfg.channels.append(channel)
+                self.cfg.save()
 
     def part(self, channel):
         """ leave channel. """
         if not channel: return
         self._raw('PART %s' % channel)
         try:
-            self.state.data['joinedchannels'].remove(channel)
-            self.state.save()
+            self.cfg.channels.remove(channel)
+            self.cfg.save()
         except (KeyError, ValueError) as ex:
-            logging.error("error removing %s from joinedchannels: %s" % (channel, str(ex)))
+            logging.error("error removing %s from bot.cfg.channels: %s" % (channel, str(ex)))
         if self.cfg.channels and channel in self.cfg.channels: self.cfg.channels.remove(channel) ; self.cfg.save()
 
     def who(self, who):
