@@ -179,7 +179,7 @@ class BotBase(LazyDict):
 
     def broadcast(self, txt):
         """ broadcast txt to all joined channels. """
-        for chan in self.state['joinedchannels']:
+        for chan in self.cfg.channels:
             self.say(chan, txt)
 
     def _eventloop(self):
@@ -242,7 +242,6 @@ class BotBase(LazyDict):
     def setstate(self, state=None):
         """ set state on the bot. """
         self.state = state or Pdod(self.datadir + os.sep + 'state')
-        if self.state and not 'joinedchannels' in self.state.data: self.state.data.joinedchannels = []
 
     def setusers(self, users=None):
         """ set users on the bot. """
@@ -263,10 +262,10 @@ class BotBase(LazyDict):
         time.sleep(getmainconfig().waitforjoin or 1)
         target = self.cfg.channels
         try:
-            for i in self.state['joinedchannels']:
+            for i in self.cfg.channels:
                 if i not in target: target.append(i)
         except: pass
-        if not target: target = self.state['joinedchannels']
+        if not target: target = self.cfg.channels
         for i in target:
             try:
                 logging.debug("%s - joining %s" % (self.cfg.name, i))
@@ -607,9 +606,10 @@ class BotBase(LazyDict):
         e.bonded = True
         e.isoutput = True
         e.dontbind = True
+        logging.warn("> first_callbacks > %s" % e.txt) 
         first_callbacks.check(self, e)
 
-    def make_event(self, origin, channel, txt, event=None, wait=0, showall=False, nooutput=False, cbtype=""):
+    def make_event(self, origin, channel, txt, event=None, wait=0, showall=False, nooutput=False, cbtype="", push=[]):
         """ insert an event into the callbacks chain. """
         if event: e = cpy(event)
         else: e = EventBase(bot=self)
@@ -625,6 +625,8 @@ class BotBase(LazyDict):
         e.wait = wait
         e.closequeue = False
         e.prepare(self)
+        for p in push:
+            p.check(self, e)
         return e
 
     def execstr(self, origin, channel, txt, event=None, wait=0, showall=False, nooutput=False):
