@@ -228,7 +228,7 @@ class EventBase(LazyDict):
             if self.user: dolog and logging.debug("user bonded from %s" % whichmodule())
         if not self.user and target: dolog and self.iscommand and logging.warn("no %s user found" % target) ; self.nodispatch = True
         self.prepare(bot)
-        if self.bot: self.inchan = self.channel in self.bot.state.data.joinedchannels
+        if self.bot: self.inchan = self.channel in self.bot.cfg.channels
         self.bonded = True
         return self
 
