@@ -75,9 +75,9 @@ def handle_plugreload(bot, ievent):
                 logging.warn("%s reloaded" % plug) 
         except RequireError as ex: errors.append(str(ex)) ; continue
         except NoSuchPlugin: errors.append("can't find %s plugin" % plug) ; continue
-        except Exception as ex:
-            if 'No module named' in str(ex) and plug in str(ex):
-                logging.debug('%s - %s' % (modname, str(ex)))
+        except ImportError as ex:
+            if plug in str(ex):
+                logging.warn('%s - %s' % (modname, str(ex)))
                 continue
             errors.append(exceptionmsg())
     for modname in reloaded:
