@@ -33,7 +33,7 @@ from fbf.utils.pdol import Pdol
 from fbf.lib.users import users
 from fbf.utils.id import getrssid
 from fbf.lib.tasks import taskmanager
-from fbf.lib.callbacks import callbacks
+from fbf.lib.callbacks import callbacks, last_callbacks
 from fbf.lib.fleet import getfleet
 from fbf.lib.threadloop import TimedLoop
 from fbf.lib.threads import start_new_thread
@@ -322,6 +322,7 @@ sleeptime=15*60, running=0):
                         if hashtag: response += " %s" % hashtag
                         try: bot.say(nick or channel, response, how=how, speed=-1, **{'headlines': True}) ; nritems += 1
                         except Exception as ex: handle_exception()
+                        bot.make_event(name, channel, response, cbtype="RSS", push=[last_callbacks,])
                 else:
                     sep =  self.markup.get(jsonstring([name, type, channel]), 'separator')
                     if sep: response = self.makeresponse(name, type, res2, channel, sep=sep)
@@ -825,6 +826,15 @@ def save():
     """ save watcher data. """
     watcher.save()
 
+## rss-test command
+
+def handle_rsstest(bot, event):
+    bot.make_event(event.userhost, event.channel, event.rest, event=event, cbtype="RSS", push=[last_callbacks,])
+    event.done()
+
+cmnds.add("rss-test", handle_rsstest, "OPER")
+examples.add("rss-test", "test the RSS event", "rss-test")
+
 ## rss-lastpoll command
 
 def handle_rsslastpoll(bot, event):
