@@ -8,6 +8,7 @@
 
 from fbf.utils.exception import handle_exception
 from fbf.lib.commands import cmnds
+from fbf.lib.callbacks import callbacks, first_callbacks, last_callbacks
 from fbf.lib.examples import examples
 from fbf.utils.pdol import Pdol
 from fbf.utils.textutils import html_unescape
@@ -27,6 +28,26 @@ import urllib.request, urllib.error, urllib.parse
 import types
 import logging
 
+## load on start
+
+def twitterstart(bot, event): pass
+
+callbacks.add("START", twitterstart)
+
+## twitter callbacks
+
+def twittercb(bot, event):
+    event.dontbind = False
+    event.bind(force=True)
+    try: twittername = event.chan.data.twittername
+    except Exception as ex: handle_exception() ; twittername = None
+    try: username = event.origin ; logging.info("using origin %s" % event.origin)
+    except Exception as ex: handle_exception() ; username = None
+    try: twitter_out(twittername or username or "fbfbot", event.txt, event)
+    except Exception as ex: logging.warn("error posting to twitter: %s" % str(ex))
+
+last_callbacks.add("RSS", twittercb)
+
 ## twitter command
 
 def handle_twitter(bot, ievent):
@@ -87,6 +108,14 @@ def handle_twittercmnd(bot, ievent):
 cmnds.add('twitter-cmnd', handle_twittercmnd, 'OPER')
 examples.add('twitter-cmnd', 'do a cmnd on the twitter API', 'twitter-cmnd home_timeline')
 
+## twitter-users command
+
+def handle_twitterusers(bot, event):
+    event.reply("twitter users: ", get_users().users())
+
+cmnds.add("twitter-users", handle_twitterusers, "OPER")
+examples.add("twitter-users", "show twitter users", "twitter-users")
+
 ## twitter-confirm command
 
 def handle_twitter_confirm(bot, ievent):
@@ -99,7 +128,7 @@ def handle_twitter_confirm(bot, ievent):
     except (tweepy.TweepError, urllib.error.HTTPError) as e: ievent.reply('twitter failed: %s' % (str(e),)) ; return
     twitteruser = get_users()
     twitteruser.add(ievent.user.data.name, access_token.to_string())
-    ievent.reply("access token saved.")
+    ievent.reply("%s access token saved." % ievent.user.data.name)
 
 cmnds.add('twitter-confirm', handle_twitter_confirm, ['OPER', 'USER', 'GUEST'])
 examples.add('twitter-confirm', 'confirm your twitter account', 'twitter-confirm 6992762')
