@@ -15,20 +15,25 @@ import logging.handlers
 import os
 import os.path
 import getpass
+import copy
 
 ## defines
 
+cpy = copy.deepcopy
+
 logfilter = []
 logplugs = []
+errors = []
 
 TAGS = { 
          'looponce': logging.DEBUG,
          'dosync': logging.INFO,
          'TICK': logging.DEBUG,
-         'TICK60': logging.DEBUG,
-         'runner.cleanup': logging.INFO,
+         'cleanup': logging.INFO,
          'sleeptime': logging.INFO,
-         'lastpoll': logging.INFO
+         'lastpoll': logging.INFO,
+         'ticksave': logging.DEBUG,
+         'periodical': logging.DEBUG
        }           
 
 ERASE_LINE = '\033[2K'
@@ -78,6 +83,7 @@ filehandler = None
 class MyFilter(logging.Filter):
 
     def filter(self, record):
+        if record.levelno == logging.error: errors.append(cpy(record.msg))
         for f in logfilter:
             if f in record.msg: return False
         for modname in logplugs:
@@ -89,6 +95,9 @@ class MyFilter(logging.Filter):
            if tag in record.msg:
                 try: record.levelno = l ; record.levelname = RLEVELS[l] ; got = True
                 except KeyError as ex: pass
+        lname = record.levelname
+        if "ERROR" in lname or "CRITICAL" in lname: record.name = "%s%s%s" % (RED, lname[0].upper(), ENDC)
+        else: record.name = lname[0].upper()
         if got: return True
         return True
 
@@ -100,8 +109,8 @@ def setloglevel(level_name="warn", colors=True, datadir=None):
     global level
     global filehandler
     LOGDIR = init(getdatadir())
-    format_short = "\033[1m%(asctime)-8s\033[0m -=- %(levelname)-8s -=- \033[93m%(message)-75s\033[0m -=- \033[92m%(module)s.%(funcName)s.%(lineno)s\033[0m -=- \033[94m%(threadName)s\033[0m"
-    format_short_plain = "%(asctime)-8s -=- %(levelname)-8s -=- %(message)-75s -=- %(module)s.%(funcName)s.%(lineno)s -=- %(threadName)s"
+    format_short = "\033[1m%(asctime)-8s\033[0m -=- %(name)-1s -=- \033[93m%(message)-75s\033[0m -=- \033[92m%(module)s.%(funcName)s.%(lineno)s\033[0m -=- \033[94m%(threadName)s\033[0m"
+    format_short_plain = "%(asctime)-8s -=- %(name)-1s -=- %(message)-75s -=- %(module)s.%(funcName)s.%(lineno)s -=- %(threadName)s"
     datefmt = '%H:%M:%S'
     formatter_short = logging.Formatter(format_short, datefmt=datefmt)
     formatter_short_plain = logging.Formatter(format_short_plain, datefmt=datefmt)
