@@ -7,6 +7,7 @@
 ## fbf imports
 
 from fbf.utils.lazydict import LazyDict
+from fbf.lib.errors import WrongType
 
 ## basic imports
 
@@ -18,6 +19,12 @@ class StatDict(LazyDict):
 
     """ dictionary to hold stats """
 
+    def __iadd__(self, b):
+        if not type(b) == StatDict: raise WrongType(type(b))
+        for key, value in b.items():
+            self.upitem(key, value)
+        return self
+
     def set(self, item, value):
         """ set item to value """
         self[item] = value
@@ -53,3 +60,14 @@ class StatDict(LazyDict):
         result.sort(reverse=True)
         if limit: return result[:limit]
         else: return result
+
+    def countdictkeys(self, d):   
+        """ count all keys of a dict. """
+        for key in d:
+            self.upitem(key)
+
+    def countdictvalues(self, d):
+        """ count all keys of a dict. """
+        for key, value in d.items():
+            try: self.upitem(value)
+            except TypeError: pass
